package com.cisco.axl.demo;

/**
 * THIS SAMPLE APPLICATION AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
 * OF ANY KIND BY CISCO, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY FITNESS FOR A PARTICULAR
 * PURPOSE, NONINFRINGEMENT, SATISFACTORY QUALITY OR ARISING FROM A COURSE OF
 * DEALING, LAW, USAGE, OR TRADE PRACTICE. CISCO TAKES NO RESPONSIBILITY
 * REGARDING ITS USAGE IN AN APPLICATION, AND IT IS PRESENTED ONLY AS AN
 * EXAMPLE. THE SAMPLE CODE HAS NOT BEEN THOROUGHLY TESTED AND IS PROVIDED AS AN
 * EXAMPLE ONLY, THEREFORE CISCO DOES NOT GUARANTEE OR MAKE ANY REPRESENTATIONS
 * REGARDING ITS RELIABILITY, SERVICEABILITY, OR FUNCTION. IN NO EVENT DOES
 * CISCO WARRANT THAT THE SOFTWARE IS ERROR FREE OR THAT CUSTOMER WILL BE ABLE
 * TO OPERATE THE SOFTWARE WITHOUT PROBLEMS OR INTERRUPTIONS. NOR DOES CISCO
 * WARRANT THAT THE SOFTWARE OR ANY EQUIPMENT ON WHICH THE SOFTWARE IS USED WILL
 * BE FREE OF VULNERABILITY TO INTRUSION OR ATTACK. THIS SAMPLE APPLICATION IS
 * NOT SUPPORTED BY CISCO IN ANY MANNER. CISCO DOES NOT ASSUME ANY LIABILITY
 * ARISING FROM THE USE OF THE APPLICATION. FURTHERMORE, IN NO EVENT SHALL CISCO
 * OR ITS SUPPLIERS BE LIABLE FOR ANY INCIDENTAL OR CONSEQUENTIAL DAMAGES, LOST
 * PROFITS, OR LOST DATA, OR ANY OTHER INDIRECT DAMAGES EVEN IF CISCO OR ITS
 * SUPPLIERS HAVE BEEN INFORMED OF THE POSSIBILITY THEREOF.
 */

import java.util.concurrent.Future;

import javax.xml.ws.BindingProvider;
import javax.xml.ws.soap.AddressingFeature;

import com.cisco.axlapiservice.AXLAPIService;
import com.cisco.axlapiservice.AXLPort;
import com.cisco.axl.api._8.*;


/**
 * <p>
 * Performs getPhone operation using AXL API
 * </p>
 * 
 * <p>
 * Note, the service consumers were generated by the Java 6 wsimport command:
 * </p>
 * 
 * <p>
 * <code>
 * wsimport -keep -b schema/current/AXLSOAP.xsd -Xnocompile  -s src -d bin -verbose schema/current/AXLAPI.wsdl
 * </code>
 * </p>
 * 
 * <p>
 * And since AXL uses HTTPS you will have to install the UC application's
 * certificate into a local keystore in order to run this sample app:
 * </p>
 * 
 * <p>
 * <code> 
 * java -cp . -Djavax.net.ssl.trustStore=mystore -Djavax.net.ssl.trustStorePassword="mypasswd" com.cisco.paws.demo.Upgrade
 * </code>
 * </p>
 * 
 * @author awhaley
 */
public class Demo {

    

    /**
     * UC app host.
     */
    protected static String ucHost = null;

    /**
     * OS admin.
     */
    protected static String ucAdmin = null;

    /**
     * OS admin password.
     */
    protected static String ucPswd = null;

    /**
     * phoneName.
     */
    protected static  String phoneName = null;

    /**
     * Run the demo
     * 
     * @param args Not used.
     */
    public static void main(String[] args) {
        // Verify JVM has a console
        if (System.console() == null) {
            System.err.println("The Cisco AXL Sample App requires a console.");
            System.exit(1);
        } else {
            Demo.informUser("%nWelcome to the Cisco AXL Sample APP.%n");
        }

        Demo demo = new Demo();
        demo.getPhoneInfo();
    }

    /**
     * get information about a Phone
     */
    public void getPhoneInfo() {
        // Ask for the UC application to upgrade
//        Demo.informUser("%nWhat UC server would you like to access?%n");
    	  ucHost = promptUser("  Host: ");
          ucAdmin = promptUser("  OS Admin Account: ");
          ucPswd = promptUser("  OS Admin Password: ");

     // Ask for the phone name 
        Demo.informUser("%nEnter the name of the phone you want to retrieve information about.%n");
        phoneName = promptUser("  Phone Name: ");

        
        // Select the upgrade
        getPhone();

    }

    /**
     * Prompts user for a valid upgrade file.
     */
    private void getPhone() {
       
            // Instantiate the wsimport generated AXL API Service client --
            // see the wsimport comments in the class javadocs above
            AXLAPIService axlService = new AXLAPIService();
            AXLPort axlPort = axlService.getAXLPort();	
                        
            
            // Set the URL, user, and password on the JAX-WS client
            String validatorUrl = "https://"
                    + Demo.ucHost
                    + ":8443/axl/";
            
            
            ((BindingProvider) axlPort).getRequestContext().put(
                    BindingProvider.ENDPOINT_ADDRESS_PROPERTY, validatorUrl);
            ((BindingProvider) axlPort).getRequestContext().put(
                    BindingProvider.USERNAME_PROPERTY, Demo.ucAdmin);
            ((BindingProvider) axlPort).getRequestContext().put(
                    BindingProvider.PASSWORD_PROPERTY, Demo.ucPswd);

            // Make a synchronous call to the UpgradeValid service
            GetPhoneReq axlParams = new GetPhoneReq();
            axlParams.setName(phoneName);
            
            GetPhoneRes getPhoneResponse = axlPort.getPhone(axlParams);
           
            Demo.informUser("Product=" + getPhoneResponse.getReturn().getPhone().getProduct() + "%n");
        }

    // -------------- Some I/O Helper Methods --------------

    /**
     * Provide the user some instructions.
     */
    protected static void informUser(String info) {
        System.console().format(info);
    }

    /**
     * Ask the user a question.
     * 
     * @return A non-null, non-empty answer to the question.
     */
    protected static String promptUser(String question) {
        String answer = null;
        while (answer == null || answer.isEmpty()) {
            answer = System.console().readLine(question);
        }
        return answer.trim();
    }
}